"use strict";
"use client";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EditorInterface = EditorInterface;
const jsx_runtime_1 = require("react/jsx-runtime");
const starter_kit_1 = __importDefault(require("@tiptap/starter-kit"));
const react_1 = require("@tiptap/react");
const extension_task_item_1 = __importDefault(require("@tiptap/extension-task-item"));
const extension_task_list_1 = __importDefault(require("@tiptap/extension-task-list"));
const extension_table_1 = __importDefault(require("@tiptap/extension-table"));
const extension_table_cell_1 = __importDefault(require("@tiptap/extension-table-cell"));
const extension_table_header_1 = __importDefault(require("@tiptap/extension-table-header"));
const extension_table_row_1 = __importDefault(require("@tiptap/extension-table-row"));
const extension_underline_1 = __importDefault(require("@tiptap/extension-underline"));
const extension_font_family_1 = __importDefault(require("@tiptap/extension-font-family"));
const extension_text_style_1 = __importDefault(require("@tiptap/extension-text-style"));
const extension_superscript_1 = __importDefault(require("@tiptap/extension-superscript"));
const extension_subscript_1 = __importDefault(require("@tiptap/extension-subscript"));
const extension_color_1 = require("@tiptap/extension-color");
const extension_highlight_1 = __importDefault(require("@tiptap/extension-highlight"));
const extension_link_1 = __importDefault(require("@tiptap/extension-link"));
const extension_text_align_1 = __importDefault(require("@tiptap/extension-text-align"));
const tiptap_extension_resize_image_1 = require("tiptap-extension-resize-image");
const extension_horizontal_rule_1 = __importDefault(require("@tiptap/extension-horizontal-rule"));
const useEditorState_1 = require("../store/useEditorState");
const Ruler_1 = require("./Ruler");
const font_size_1 = require("../extensions/font-size");
const line_height_1 = require("../extensions/line-height");
const page_break_1 = require("../extensions/page-break");
function EditorInterface() {
    const { setEditor } = (0, useEditorState_1.useEditorStore)();
    const editor = (0, react_1.useEditor)({
        immediatelyRender: false,
        onCreate({ editor }) {
            setEditor(editor);
        },
        onDestroy() {
            setEditor(null);
        },
        onUpdate: ({ editor }) => {
            setEditor(editor);
        },
        onSelectionUpdate: ({ editor }) => {
            setEditor(editor);
        },
        onTransaction: ({ editor }) => {
            setEditor(editor);
        },
        onFocus: ({ editor }) => {
            setEditor(editor);
        },
        onBlur: ({ editor }) => {
            setEditor(editor);
        },
        onContentError: ({ editor }) => {
            setEditor(editor);
        },
        editorProps: {
            attributes: {
                style: "padding-left:56px; padding-right:56px;",
                class: "focus:outline-none print:border-0 bg-white border border[#C7C7C7] flex flex-col min-h-[1054px] w-[816px] pt-10 pr-14 pb-10 cursor-text",
            },
        },
        extensions: [
            starter_kit_1.default,
            line_height_1.LineHeight.configure({
                types: ["paragraph", "heading"],
            }),
            font_size_1.FontSize,
            page_break_1.PageBreak,
            extension_horizontal_rule_1.default,
            extension_superscript_1.default,
            extension_subscript_1.default,
            extension_text_align_1.default.configure({
                types: ["heading", "paragraph"],
            }),
            extension_link_1.default.configure({
                openOnClick: false,
                autolink: true,
                defaultProtocol: "https",
            }),
            extension_highlight_1.default.configure({ multicolor: true }),
            extension_text_style_1.default,
            extension_color_1.Color,
            extension_font_family_1.default,
            extension_underline_1.default,
            tiptap_extension_resize_image_1.ImageResize,
            extension_task_list_1.default,
            extension_task_item_1.default.configure({
                nested: true,
            }),
            extension_table_1.default.configure({
                resizable: true,
            }),
            extension_table_row_1.default,
            extension_table_header_1.default,
            extension_table_cell_1.default,
        ],
        content: "",
    });
    return ((0, jsx_runtime_1.jsxs)("div", { className: "size-full overflow-x-auto bg-[#F9F8FD] px-0 print:p-0 print:bg-white print:overflow-visible", children: [(0, jsx_runtime_1.jsx)(Ruler_1.Ruler, {}), (0, jsx_runtime_1.jsx)("div", { className: "min-w-max flex justify-center w-[816px] py-4 print:py-0 mx-auto print:w-full print:min-w-0", children: (0, jsx_runtime_1.jsx)(react_1.EditorContent, { editor: editor }) })] }));
}
