"use strict";
"use client";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuBar = MenuBar;
const jsx_runtime_1 = require("react/jsx-runtime");
const menubar_1 = require("./ui/menubar");
const fa_1 = require("react-icons/fa");
const lu_1 = require("react-icons/lu");
const ti_1 = require("react-icons/ti");
const bs_1 = require("react-icons/bs");
const useEditorState_1 = require("../store/useEditorState");
function MenuBar({ onSave, onClose }) {
    const { editor } = (0, useEditorState_1.useEditorStore)();
    function insertTable(selected) {
        editor === null || editor === void 0 ? void 0 : editor.chain().focus().insertTable({ rows: selected, cols: selected, withHeaderRow: false }).run();
    }
    function onExport(blob, filename) {
        const url = window.URL.createObjectURL(blob);
        const a = document.createElement("a");
        a.href = url;
        a.download = filename;
        a.click();
        window.URL.revokeObjectURL(url);
    }
    function onExportJSON() {
        if (!editor)
            return;
        const json = editor === null || editor === void 0 ? void 0 : editor.getJSON();
        const blob = new Blob([JSON.stringify(json)], { type: "application/json" });
        onExport(blob, "document.json");
    }
    function onExportHTML() {
        if (!editor)
            return;
        const html = editor === null || editor === void 0 ? void 0 : editor.getHTML();
        const blob = new Blob([html], { type: "text/html" });
        onExport(blob, "document.html");
    }
    function onExportText() {
        if (!editor)
            return;
        const text = editor === null || editor === void 0 ? void 0 : editor.getText();
        const blob = new Blob([text], { type: "text/plain" });
        onExport(blob, "document.txt");
    }
    return ((0, jsx_runtime_1.jsx)("div", { className: "px-4", children: (0, jsx_runtime_1.jsxs)(menubar_1.Menubar, { className: "border-none bg-transparent shadow-none h-auto p-0", children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarMenu, { children: [(0, jsx_runtime_1.jsx)(menubar_1.MenubarTrigger, { className: "menu-trigger", children: "File" }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarContent, { className: "print:hidden", children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarSub, { children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarSubTrigger, { className: "gap-2", children: [(0, jsx_runtime_1.jsx)(ti_1.TiExport, { size: 16 }), "Export as"] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarSubContent, { children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => window.print(), children: [(0, jsx_runtime_1.jsx)(fa_1.FaFilePdf, { size: 16 }), "PDF"] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: onExportHTML, children: [(0, jsx_runtime_1.jsx)(lu_1.LuGlobe, { size: 16 }), "HTML"] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: onExportJSON, children: [(0, jsx_runtime_1.jsx)(bs_1.BsFiletypeJson, { size: 16 }), "JSON"] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: onExportText, children: [(0, jsx_runtime_1.jsx)(lu_1.LuTextCursor, { size: 16 }), "Text"] })] })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => window.print(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuPrinter, { size: 16 }), "Print Document"] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => onSave === null || onSave === void 0 ? void 0 : onSave((editor === null || editor === void 0 ? void 0 : editor.getHTML()) || ""), children: [(0, jsx_runtime_1.jsx)(lu_1.LuSave, { size: 16 }), "Save"] }), (0, jsx_runtime_1.jsx)(menubar_1.MenubarSeparator, {}), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: onClose, children: [(0, jsx_runtime_1.jsx)(lu_1.LuX, { size: 16 }), "Close"] })] })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarMenu, { children: [(0, jsx_runtime_1.jsx)(menubar_1.MenubarTrigger, { className: "menu-trigger", children: "Edit" }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarContent, { children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().undo().run(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuUndo2, { size: 16 }), "Undo", (0, jsx_runtime_1.jsx)(menubar_1.MenubarShortcut, { children: "Ctrl+Z" })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().redo().run(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuRedo2, { size: 16 }), "Redo", (0, jsx_runtime_1.jsx)(menubar_1.MenubarShortcut, { children: "Ctrl+Y" })] })] })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarMenu, { children: [(0, jsx_runtime_1.jsx)(menubar_1.MenubarTrigger, { className: "menu-trigger", children: "Insert" }), (0, jsx_runtime_1.jsx)(menubar_1.MenubarContent, { children: (0, jsx_runtime_1.jsxs)(menubar_1.MenubarSub, { children: [(0, jsx_runtime_1.jsx)(menubar_1.MenubarSubTrigger, { children: "Table" }), (0, jsx_runtime_1.jsx)(menubar_1.MenubarSubContent, { children: Array.from({ length: 5 }, (_, i) => i + 1).map((n) => ((0, jsx_runtime_1.jsx)(menubar_1.MenubarItem, { onClick: () => insertTable(n), children: `${n} x ${n}` }, n))) })] }) })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarMenu, { children: [(0, jsx_runtime_1.jsx)(menubar_1.MenubarTrigger, { className: "menu-trigger", children: "Format" }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarContent, { children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarSub, { children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarSubTrigger, { className: "gap-2", children: [(0, jsx_runtime_1.jsx)(lu_1.LuText, { size: 16 }), "Text"] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarSubContent, { children: [(0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleBold().run(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuBold, { size: 16 }), "Bold", (0, jsx_runtime_1.jsx)(menubar_1.MenubarShortcut, { children: "Ctrl+B" })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleItalic().run(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuItalic, { size: 16 }), "Italic", (0, jsx_runtime_1.jsx)(menubar_1.MenubarShortcut, { children: "Ctrl+I" })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleUnderline().run(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuUnderline, { size: 16 }), "Underline", (0, jsx_runtime_1.jsx)(menubar_1.MenubarShortcut, { children: "Ctrl+U" })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleStrike().run(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuStrikethrough, { size: 16 }), "Strikethrough \u00A0 \u00A0", (0, jsx_runtime_1.jsx)(menubar_1.MenubarShortcut, { children: "Ctrl+K" })] })] })] }), (0, jsx_runtime_1.jsxs)(menubar_1.MenubarItem, { className: "gap-2", onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().unsetAllMarks().run(), children: [(0, jsx_runtime_1.jsx)(lu_1.LuRemoveFormatting, { size: 16 }), "Clear Formatting"] })] })] })] }) }));
}
