"use strict";
"use client";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ruler = Ruler;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const fa_1 = require("react-icons/fa");
const constants_1 = require("../lib/constants");
const markers = Array.from({ length: 83 }, (_, i) => i);
function Ruler() {
    const [leftMargin, setLeftMargin] = (0, react_1.useState)(constants_1.DEFAULT_RULER_MARGIN);
    const [rightMargin, setRightMargin] = (0, react_1.useState)(constants_1.DEFAULT_RULER_MARGIN);
    const [isDraggingLeft, setIsDraggingLeft] = (0, react_1.useState)(false);
    const [isDraggingRight, setIsDraggingRight] = (0, react_1.useState)(false);
    const rulerRef = (0, react_1.useRef)(null);
    function handleLeftMouseDown() {
        setIsDraggingLeft(true);
    }
    function handleRightMouseDown() {
        setIsDraggingRight(true);
    }
    function handleMouseMove(e) {
        if ((isDraggingLeft || isDraggingRight) && rulerRef.current) {
            const container = rulerRef.current.querySelector("#ruler-container");
            if (container) {
                const containerRect = container.getBoundingClientRect();
                const relativeX = e.clientX - containerRect.left;
                const rawPosition = Math.max(0, Math.min(constants_1.PAGE_WIDTH, relativeX));
                if (isDraggingLeft) {
                    const maxLeftPosition = constants_1.PAGE_WIDTH - rightMargin - constants_1.MIN_SPACE;
                    const newLeftPosition = Math.min(maxLeftPosition, rawPosition);
                    setLeftMargin(newLeftPosition);
                }
                else if (isDraggingRight) {
                    const maxRightPosition = constants_1.PAGE_WIDTH - (leftMargin + constants_1.MIN_SPACE);
                    const newRightPosition = Math.max(constants_1.PAGE_WIDTH - rawPosition, 0);
                    const contraintRightPosition = Math.min(maxRightPosition, newRightPosition);
                    setRightMargin(contraintRightPosition);
                }
            }
        }
    }
    function handleMouseUp() {
        setIsDraggingLeft(false);
        setIsDraggingRight(false);
    }
    function handleLeftDoubleClick() {
        setLeftMargin(constants_1.DEFAULT_RULER_MARGIN);
    }
    function handleRightDoubleClick() {
        setRightMargin(constants_1.DEFAULT_RULER_MARGIN);
    }
    return ((0, jsx_runtime_1.jsx)("div", { ref: rulerRef, onMouseMove: handleMouseMove, onMouseUp: handleMouseUp, onMouseLeave: handleMouseUp, className: "w-[816px] mx-auto h-6 border-b border-gray-300 flex items-end relative select-none print:hidden", children: (0, jsx_runtime_1.jsxs)("div", { id: "ruler-container", className: "w-full h-full relative", children: [(0, jsx_runtime_1.jsx)(Marker, { position: leftMargin, isLeft: true, isDragging: isDraggingLeft, onMouseDown: handleLeftMouseDown, onDoudleClick: handleLeftDoubleClick }), (0, jsx_runtime_1.jsx)(Marker, { position: rightMargin, isLeft: false, isDragging: isDraggingRight, onMouseDown: handleRightMouseDown, onDoudleClick: handleRightDoubleClick }), (0, jsx_runtime_1.jsx)("div", { className: "absolute inset-x-0 bottom-0 h-full", children: (0, jsx_runtime_1.jsx)("div", { className: "relative h-full w-[816px]", children: markers.map((marker) => {
                            const position = (marker * constants_1.PAGE_WIDTH) / 82;
                            return ((0, jsx_runtime_1.jsxs)("div", { className: "absolute bottom-0", style: { left: `${position}px` }, children: [marker % 10 === 0 && ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)("span", { className: "absolute bottom-0 w-[1px] h-2 bg-neutral-500" }), (0, jsx_runtime_1.jsx)("span", { className: "absolute bottom-2 text-[10px] text-neutral-500 transform -translate-x-1/2", children: marker / 10 + 1 })] })), marker % 5 === 0 && marker % 10 !== 0 && ((0, jsx_runtime_1.jsx)("span", { className: "absolute bottom-0 w-[1px] h-1.5 bg-neutral-500" })), marker % 5 !== 0 && ((0, jsx_runtime_1.jsx)("span", { className: "absolute bottom-0 w-[1px] h-1 bg-neutral-500" }))] }, marker));
                        }) }) })] }) }));
}
function Marker({ position, isLeft, isDragging, onMouseDown, onDoudleClick, }) {
    return ((0, jsx_runtime_1.jsxs)("div", { className: "absolute top-0 w-4 h-full cursor-ew-resize z-[5] group -ml-2", style: { [isLeft ? "left" : "right"]: `${position}px` }, onMouseDown: onMouseDown, onDoubleClick: onDoudleClick, children: [(0, jsx_runtime_1.jsx)(fa_1.FaCaretDown, { className: "absolute left-1/2 top-0 h-full fill-blue-500 transform -translate-x-1/2" }), (0, jsx_runtime_1.jsx)("div", { className: "absolute left-1/2 top-4 transform -translate-x-1/2 transition-opacity duration-150 !h-screen w-[1px] bg-blue-500 scale-x-50", style: {
                    display: isDragging ? "block" : "none",
                } })] }));
}
