"use strict";
"use client";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Toolbar = Toolbar;
const jsx_runtime_1 = require("react/jsx-runtime");
const utils_1 = require("../lib/utils");
const lu_1 = require("react-icons/lu");
const go_1 = require("react-icons/go");
const im_1 = require("react-icons/im");
const separator_1 = require("./ui/separator");
const FontFamily_1 = require("./FontFamily");
const Heading_1 = require("./Heading");
const TextColor_1 = require("./TextColor");
const useEditorState_1 = require("../store/useEditorState");
const HighlightColor_1 = require("./HighlightColor");
const Link_1 = require("./Link");
const LinkUnset_1 = require("./LinkUnset");
const Image_1 = require("./Image");
const TextAlignment_1 = require("./TextAlignment");
const List_1 = require("./List");
const FontSize_1 = require("./FontSize");
const LineHeight_1 = require("./LineHeight");
function ToolbarButton({ label, onClick, isActive, icon: Icon, }) {
    return ((0, jsx_runtime_1.jsx)("button", { onClick: onClick, className: (0, utils_1.cn)("text-sm h-7 min-w-7 flex items-center justify-center rounded-sm hover:bg-neutral-200/80", isActive && "bg-neutral-200/80"), title: label, children: (0, jsx_runtime_1.jsx)(Icon, { size: 16 }) }));
}
function Toolbar({ onSave }) {
    const { editor } = (0, useEditorState_1.useEditorStore)();
    const sections = [
        [
            {
                label: "Undo",
                icon: lu_1.LuUndo2,
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().undo().run(),
            },
            {
                label: "Redo",
                icon: lu_1.LuRedo2,
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().redo().run(),
            },
            {
                label: "Save",
                icon: lu_1.LuSave,
                onClick: () => onSave === null || onSave === void 0 ? void 0 : onSave(editor === null || editor === void 0 ? void 0 : editor.getHTML()),
            },
            {
                label: "Print",
                icon: lu_1.LuPrinter,
                onClick: () => window.print(),
            },
            {
                label: "Spell Check",
                icon: lu_1.LuSpellCheck,
                isActive: (editor === null || editor === void 0 ? void 0 : editor.view.dom.getAttribute("spellcheck")) === "true",
                onClick: () => {
                    const current = editor === null || editor === void 0 ? void 0 : editor.view.dom.getAttribute("spellcheck");
                    editor === null || editor === void 0 ? void 0 : editor.view.dom.setAttribute("spellcheck", current === "true" ? "false" : "true");
                    editor === null || editor === void 0 ? void 0 : editor.chain().focus().run();
                },
            },
        ],
        [
            {
                label: "Bold",
                icon: lu_1.LuBold,
                isActive: editor === null || editor === void 0 ? void 0 : editor.isActive("bold"),
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleBold().run(),
            },
            {
                label: "Italic",
                icon: lu_1.LuItalic,
                isActive: editor === null || editor === void 0 ? void 0 : editor.isActive("italic"),
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleItalic().run(),
            },
            {
                label: "Underline",
                icon: lu_1.LuUnderline,
                isActive: editor === null || editor === void 0 ? void 0 : editor.isActive("underline"),
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleUnderline().run(),
            },
            {
                label: "Strikethrough",
                icon: lu_1.LuStrikethrough,
                isActive: editor === null || editor === void 0 ? void 0 : editor.isActive("strike"),
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleStrike().run(),
            },
            {
                label: "Superscript",
                icon: lu_1.LuSuperscript,
                isActive: editor === null || editor === void 0 ? void 0 : editor.isActive("superscript"),
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleSuperscript().run(),
            },
            {
                label: "Subscript",
                icon: lu_1.LuSubscript,
                isActive: editor === null || editor === void 0 ? void 0 : editor.isActive("subscript"),
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleSubscript().run(),
            },
            {
                label: "Horizontal Rule",
                icon: go_1.GoHorizontalRule,
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().setHorizontalRule().run(),
            },
        ],
        [
            {
                label: "Todo List",
                icon: lu_1.LuListTodo,
                isActive: editor === null || editor === void 0 ? void 0 : editor.isActive("taskList"),
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().toggleTaskList().run(),
            },
            {
                label: "Clear Formatting",
                icon: lu_1.LuRemoveFormatting,
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.chain().focus().unsetAllMarks().run(),
            },
            {
                label: "Inser Page Break",
                icon: im_1.ImPageBreak,
                onClick: () => editor === null || editor === void 0 ? void 0 : editor.commands.insertPageBreak(),
            },
            // {
            //   label: "Comment",
            //   icon: LuMessageSquare,
            //   onClick: () => console.log("comment clicked"),
            // },
        ],
    ];
    return ((0, jsx_runtime_1.jsxs)("div", { className: "flex items-center gap-x-0.5 bg-[#F1F4F9] px-4 rounded-[0px] min-h-[40px] overflow-x-auto", children: [sections[0].map((section) => ((0, jsx_runtime_1.jsx)(ToolbarButton, Object.assign({}, section), section.label))), (0, jsx_runtime_1.jsx)(separator_1.Separator, { className: "h-6 bg-neutral-300" }), (0, jsx_runtime_1.jsx)(FontFamily_1.FontFamily, {}), (0, jsx_runtime_1.jsx)(separator_1.Separator, { className: "h-6 bg-neutral-300" }), (0, jsx_runtime_1.jsx)(FontSize_1.FontSize, {}), (0, jsx_runtime_1.jsx)(separator_1.Separator, { className: "h-6 bg-neutral-300" }), (0, jsx_runtime_1.jsx)(Heading_1.Heading, {}), (0, jsx_runtime_1.jsx)(separator_1.Separator, { className: "h-6 bg-neutral-300" }), sections[1].map((section) => ((0, jsx_runtime_1.jsx)(ToolbarButton, Object.assign({}, section), section.label))), (0, jsx_runtime_1.jsx)(TextColor_1.TextColor, {}), (0, jsx_runtime_1.jsx)(HighlightColor_1.HighlightColor, {}), (0, jsx_runtime_1.jsx)(separator_1.Separator, { className: "h-6 bg-neutral-300" }), (0, jsx_runtime_1.jsx)(Link_1.Link, {}), (0, jsx_runtime_1.jsx)(LinkUnset_1.LinkUnset, {}), (0, jsx_runtime_1.jsx)(Image_1.Image, {}), (0, jsx_runtime_1.jsx)(TextAlignment_1.TextAlignment, {}), (0, jsx_runtime_1.jsx)(LineHeight_1.LineHeight, {}), (0, jsx_runtime_1.jsx)(List_1.List, {}), (0, jsx_runtime_1.jsx)(separator_1.Separator, { className: "h-6 bg-neutral-300" }), sections[2].map((section) => ((0, jsx_runtime_1.jsx)(ToolbarButton, Object.assign({}, section), section.label)))] }));
}
