"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LineHeight = void 0;
const react_1 = require("@tiptap/react");
exports.LineHeight = react_1.Extension.create({
    name: "lineHeight",
    addOptions() {
        return {
            types: ["paragraph", "heading"],
            defaultlineHeight: "normal",
        };
    },
    addGlobalAttributes() {
        return [
            {
                types: this.options.types,
                attributes: {
                    lineHeight: {
                        default: this.options.defaultlineHeight,
                        renderHTML: (attributes) => {
                            if (!attributes.lineHeight) {
                                return {};
                            }
                            return {
                                style: `line-height: ${attributes.lineHeight}`,
                            };
                        },
                        parseHTML: (element) => element.style.lineHeight || this.options.defaultlineHeight,
                    },
                },
            },
        ];
    },
    addCommands() {
        return {
            setLineHeight: (lineHeight) => ({ tr, state, dispatch }) => {
                const { selection } = state;
                tr = tr.setSelection(selection);
                const { from, to } = selection;
                state.doc.nodesBetween(from, to, (node, pos) => {
                    if (this.options.types.includes(node.type.name)) {
                        tr = tr.setNodeMarkup(pos, undefined, Object.assign(Object.assign({}, node.attrs), { lineHeight }));
                    }
                });
                if (dispatch) {
                    dispatch(tr);
                }
                return true;
            },
            unsetLineHeight: () => ({ tr, state, dispatch }) => {
                const { selection } = state;
                tr = tr.setSelection(selection);
                const { from, to } = selection;
                state.doc.nodesBetween(from, to, (node, pos) => {
                    if (this.options.types.includes(node.type.name)) {
                        tr = tr.setNodeMarkup(pos, undefined, Object.assign(Object.assign({}, node.attrs), { lineHeight: this.options.defaultlineHeight }));
                    }
                });
                if (dispatch) {
                    dispatch(tr);
                }
                return true;
            },
        };
    },
});
